@@ -28,9 +28,10 @@
 
 #include <Lum/Combo.h>
 
+#include "Configuration.h"
 #include "Parser.h"
 
-class Calc : public Lum::Component
+class Calc : public Lum::Component, public ConfigPlugin
 {
 private:
   Lum::Model::ActionRef      calculate;
@@ -50,6 +51,9 @@ public:
   void CalcSize();
 
   void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);
+
+  void LoadConfig(Lum::Config::Node *top);
+  void StoreConfig(Lum::Config::Node *top);
 };
 
 #endif
